@@ -72,14 +72,17 @@ extern int msa_disp_send_request(xmlChar* target_id, xmlDocPtr msa_ui_request)
         /** create a new thread for sending request **/
         target_module->data = (gpointer)msa_ui_request;
         msa_data = (gpointer)target_module;
-        g_thread_create((GThreadFunc)start_thread, msa_data, FALSE, NULL);
+        if (g_thread_create((GThreadFunc)start_thread, msa_data, FALSE, NULL) != NULL) {
+            return SUCCESS;
+        } 
         //start_thread(msa_data);
+        
     } else {
         g_debug("disp:msa_disp_send_request: the module is not ready to work or is occupied!");
         return FAILURE;
     }
 
-    return SUCCESS;
+    return FAILURE;
 }
 
 /**
